==> vue-cli-plugin-express-dev-1.0.0.tgz: package/generator.js <==
const fs = require('fs')
const path = require('path')
const { warn,done } = require('@vue/cli-shared-utils')

module.exports = (api, options = {}) => {
  let devDependencies={},pkg = fs.readFileSync(api.resolve('./package.json'), 'utf8')
  pkg = JSON.parse(pkg)
  const addScript = (name, command) => {
    // Add on to existing script if it exists
    if (pkg.scripts && pkg.scripts[name]) {
      // Don't re-add script
      if (!pkg.scripts[name].match(command)) {
        // add command to existing script
        scripts[name] = pkg.scripts[name] + ` && ${command}`
      } else {
        // command already exists, don't change it
        scripts[name] = pkg.scripts[name]
      }
    } else {
      // Create new postinstall script
      scripts[name] = command
    }
  }
  const scripts = {
    'express:serve': 'vue-cli-service express:serve'
  }

  if(options.installRollupjsConfig){
    if (fs.existsSync(api.resolve('./rollup.config.js'))) {
      fs.renameSync(api.resolve('./rollup.config.js'), api.resolve('./rollup.config.js.bak'));
    }
    api.render({'./rollup.config.js':'./templates/rollup.config.js'});
    devDependencies={
      "@rollup/plugin-buble": "^0.21.3",
      "@rollup/plugin-commonjs": "^15.0.0",
      "@rollup/plugin-json": "^4.1.0",
      "@rollup/plugin-replace": "^2.3.3",
      "builtin-modules": "^3.1.0",
      "rollup": "^2.26.10",
      "rollup-plugin-es6template": "^1.0.6",
      "rollup-plugin-generate-package-json": "^3.2.0",
      "rollup-plugin-jsonlint": "0.0.1",
      "rollup-plugin-string": "^3.0.0",
      "rollup-plugin-terser": "^7.0.2",
    }
    addScript('express:build','vue-cli-service build && rollup -c')
  }



  if (!fs.existsSync(api.resolve(options.entryDev))) {
    api.render({[`${options.entryDev}`]: './templates/src/index.dev.js'});
  }

  api.onCreateComplete(() => {
    done('vue-cli-plugin-express-dev installed \n')
  })

  api.extendPackage({
    scripts,
    devDependencies,
    vue: {
      pluginOptions: {
        express: {
          entryDev: options.entryDev,
          watchDir: options.watchDir,
        },
      },
    },
  })
}

==> vue-cli-plugin-express-dev-1.0.2.tgz: package/generator.js <==
const fs = require('fs')
const path = require('path')
const { warn,done } = require('@vue/cli-shared-utils')

module.exports = (api, options = {}) => {
  let devDependencies={},pkg = fs.readFileSync(api.resolve('./package.json'), 'utf8')
  pkg = JSON.parse(pkg)
  const addScript = (name, command) => {
    // Add on to existing script if it exists
    if (pkg.scripts && pkg.scripts[name]) {
      // Don't re-add script
      if (!pkg.scripts[name].match(command)) {
        // add command to existing script
        scripts[name] = pkg.scripts[name] + ` && ${command}`
      } else {
        // command already exists, don't change it
        scripts[name] = pkg.scripts[name]
      }
    } else {
      // Create new postinstall script
      scripts[name] = command
    }
  }
  const scripts = {
    'express:serve': 'vue-cli-service express:serve'
  }

  if(options.installRollupjsConfig && options.backupRollupjsConfig!==false){
    if (fs.existsSync(api.resolve('./rollup.config.js'))) {
      fs.renameSync(api.resolve('./rollup.config.js'), api.resolve('./rollup.config.js.bak'));
    }
    api.render({'./rollup.config.js':'./templates/rollup.config.js'});
    devDependencies={
      "@rollup/plugin-buble": "^0.21.3",
      "@rollup/plugin-commonjs": "^15.0.0",
      "@rollup/plugin-json": "^4.1.0",
      "@rollup/plugin-replace": "^2.3.3",
      "builtin-modules": "^3.1.0",
      "rollup": "^2.26.10",
      "rollup-plugin-es6template": "^1.0.6",
      "rollup-plugin-generate-package-json": "^3.2.0",
      "rollup-plugin-jsonlint": "0.0.1",
      "rollup-plugin-string": "^3.0.0",
      "rollup-plugin-terser": "^7.0.2",
    }
    addScript('express:build','vue-cli-service build && rollup -c')
  }



  if (!fs.existsSync(api.resolve(options.entryDev))) {
    api.render({[`${options.entryDev}`]: './templates/src/index.dev.js'});
  }

  api.onCreateComplete(() => {
    done('vue-cli-plugin-express-dev installed \n')
  })

  api.extendPackage({
    scripts,
    devDependencies,
    vue: {
      pluginOptions: {
        express: {
          entryDev: options.entryDev,
          watchDir: options.watchDir,
        },
      },
    },
  })
}
